@@ -166,7 +166,33 @@ encounter.delete('/:id/documentMetadata/:documentMetadataId', deleteDocumentMeta
 encounter.delete('/:id', deleteEncounter);
 
 const encounterRelations = permissionCheckingRouter('read', 'Encounter');
-encounterRelations.get('/:id/discharge', simpleGetHasOne('Discharge', 'encounterId'));
+encounterRelations.get(
+  '/:id/discharge',
+  asyncHandler(async (req, res) => {
+    const {
+      models: { Discharge },
+      params,
+    } = req;
+    req.checkPermission('read', 'Discharge');
+
+    const discharge = await Discharge.findOne({
+      where: {
+        encounterId: params.id,
+      },
+      include: Discharge.getFullReferenceAssociations(),
+    });
+    if (!discharge) throw new NotFoundError();
+    await req.audit?.access?.({
+      recordId: discharge.id,
+      params,
+      model: Discharge,
+    });
+
+    const plain = discharge.get({ plain: true });
+    plain.address = await discharge.address();
+    res.send(plain);
+  }),
+);
 encounterRelations.get('/:id/legacyVitals', simpleGetList('Vitals', 'encounterId'));
 encounterRelations.get('/:id/diagnoses', simpleGetList('EncounterDiagnosis', 'encounterId'));
 encounterRelations.get('/:id/medications', simpleGetList('EncounterMedication', 'encounterId'));
@@ -637,7 +663,7 @@ encounterRelations.get(
       ],
       limit: rowsPerPage,
       offset: page * rowsPerPage,
-      include: Task.getFullReferenceAssociations(),
+      include: [...Task.getFullReferenceAssociations(), 'parentTask'],
     });
     const results = queryResults.map((x) => x.forResponse());
 
